From f9665846e405664bec650d77f9dd236c61a293b0 Mon Sep 17 00:00:00 2001
From: Krystian Kuzniarek <krystian.kuzniarek@gmail.com>
Date: Tue, 5 Nov 2019 06:46:43 +0100
Subject: [PATCH] update gen_gtest_pred_impl.py

After 7bd4a7f3 gtest_pred_impl_unittest.cc used to be newer than
its template.
---
 googletest/scripts/gen_gtest_pred_impl.py | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/googletest/scripts/gen_gtest_pred_impl.py b/googletest/scripts/gen_gtest_pred_impl.py
index 72942779..20206e39 100755
--- a/googletest/scripts/gen_gtest_pred_impl.py
+++ b/googletest/scripts/gen_gtest_pred_impl.py
@@ -544,10 +544,10 @@ class Predicate%(n)sTest : public testing::Test {
     }
   }
 
   // true iff the test function is expected to run to finish.
   static bool expected_to_finish_;
 
   // true iff the test function did run to finish.
   static bool finished_;
 """ % DEFS
 
@@ -576,12 +576,12 @@ typedef Predicate%(n)sTest ASSERT_PRED%(n)sTest;
     """Returns the test for a predicate assertion macro.
 
     Args:
-      use_format:     true iff the assertion is a *_PRED_FORMAT*.
-      use_assert:     true iff the assertion is a ASSERT_*.
-      expect_failure: true iff the assertion is expected to fail.
-      use_functor:    true iff the first argument of the assertion is
+      use_format:     true if and only if the assertion is a *_PRED_FORMAT*.
+      use_assert:     true if and only if the assertion is a ASSERT_*.
+      expect_failure: true if and only if the assertion is expected to fail.
+      use_functor:    true if and only if the first argument of the assertion is
                       a functor (as opposed to a function)
-      use_user_type:  true iff the predicate functor/function takes
+      use_user_type:  true if and only if the predicate functor/function takes
                       argument(s) of a user-defined type.
 
     Example:
@@ -544,10 +544,10 @@ class Predicate%(n)sTest : public testing::Test {
   }
 
-  // true iff the test function is expected to run to finish.
+  // true if and only if the test function is expected to run to finish.
   static bool expected_to_finish_;
 
@@ -544,10 +544,10 @@ class Predicate%(n)sTest : public testing::Test {
   static bool expected_to_finish_;
 
-  // true iff the test function did run to finish.
+  // true if and only if the test function did run to finish.
   static bool finished_;
 """ % DEFS